@@ -1,11 +1,12 @@
 package Params::Callback;
 
 use strict;
+require 5.006;
 use Params::Validate ();
 use Params::CallbackRequest::Exceptions (abbr => [qw(throw_bad_params)]);
 
 use vars qw($VERSION);
-$VERSION = '1.17';
+$VERSION = '1.20';
 use constant DEFAULT_PRIORITY => 5;
 use constant REDIRECT => 302;
 
@@ -36,15 +37,17 @@ BEGIN {
     }
 
     # Build read-only accessors.
-    for my $attr (qw( cb_request
-                      params
-                      apache_req
-                      priority
-                      cb_key
-                      pkg_key
-                      requester
-                      trigger_key
-                      value )) {
+    for my $attr (qw(
+        cb_request
+        params
+        apache_req
+        priority
+        cb_key
+        pkg_key
+        requester
+        trigger_key
+        value
+    )) {
         no strict 'refs';
         *{$attr} = sub { $_[0]->{$attr} };
     }
@@ -116,16 +119,17 @@ sub register_subclass {
     my $class = caller;
     return unless UNIVERSAL::isa($class, __PACKAGE__)
       and $class ne __PACKAGE__;
-    my $spec = { default_priority =>
-                 { type      => Params::Validate::SCALAR,
-                   optional  => 1,
-                   callbacks => $is_num
-                 },
-                 class_key =>
-                 { type      => Params::Validate::SCALAR,
-                   optional  => 1
-                 },
-               };
+    my $spec = {
+        default_priority => {
+            type      => Params::Validate::SCALAR,
+            optional  => 1,
+            callbacks => $is_num
+        },
+        class_key => {
+            type      => Params::Validate::SCALAR,
+            optional  => 1
+        },
+    };
 
     my %p = Params::Validate::validate(@_, $spec);
 
@@ -160,12 +164,13 @@ sub Callback : ATTR(CODE, BEGIN) {
     # Validate the arguments. At this point, there's only one allowed,
     # priority. This is to set a priority for the callback method that
     # overrides that set for the class.
-    my $spec = { priority =>
-                 { type      => Params::Validate::SCALAR,
-                   optional  => 1,
-                   callbacks => $is_num
-                 },
-               };
+    my $spec = {
+        priority => {
+            type      => Params::Validate::SCALAR,
+            optional  => 1,
+            callbacks => $is_num
+        },
+    };
     my %p = Params::Validate::validate(@$data, $spec);
     # Get the priority.
     my $priority = exists $p{priority} ? $p{priority} :
@@ -320,9 +325,9 @@ sub _load_classes {
     # Process the class keys in the order they're given, or just do all of
     # them if $ckeys eq 'ALL' or $ckeys->[0]  eq '_ALL_' (checked by
     # Params::CallbackRequest).
-    foreach my $ckey (ref $ckeys && $ckeys->[0] ne '_ALL_'
-                      ? @$ckeys
-                      : keys %classes) {
+    foreach my $ckey (
+        ref $ckeys && $ckeys->[0] ne '_ALL_' ? @$ckeys : keys %classes
+    ) {
         my $class = $classes{$ckey} or
           die "Class with class key '$ckey' not loaded. Did you forget use"
             . " it or to call register_subclass()?";
@@ -1039,13 +1044,22 @@ L<Params::CallbackRequest|Params::CallbackRequest> constructs Params::Callback
 objects and executes the appropriate callback functions and/or methods. It's
 worth a read.
 
+=head1 SUPPORT
+
+This module is stored in an open repository at the following address:
+
+L<https://svn.kineticode.com/Params-CallbackRequest/trunk/>
+
+Patches against Params::CallbackRequest are welcome. Please send bug reports
+to <bug-params-callbackrequest@rt.cpan.org>.
+
 =head1 AUTHOR
 
-David Wheeler <david@kineticode.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2007 David Wheeler
+Copyright 2003-2011 David E. Wheeler. Some Rights Reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
