@@ -7,7 +7,7 @@ use Params::CallbackRequest::Exceptions (abbr => [qw(throw_bad_params
                                                      throw_cb_exec)]);
 
 use vars qw($VERSION);
-$VERSION = '1.13';
+$VERSION = '1.20';
 
 BEGIN {
     for my $attr (qw( default_priority
@@ -44,54 +44,56 @@ my $exception_handler = sub {
 };
 
 # Set up the valid parameters to new().
-my %valid_params =
-  ( default_priority =>
-    { type      => Params::Validate::SCALAR,
-      callbacks => { 'valid priority' => sub { $_[0] =~ /^\d$/ } },
-      default   => 5,
+my %valid_params = (
+    default_priority => {
+        type      => Params::Validate::SCALAR,
+        callbacks => {
+            'valid priority' => sub { $_[0] =~ /^\d$/ }
+        },
+        default => 5,
     },
 
-    default_pkg_key =>
-    { type      => Params::Validate::SCALAR,
-      default   => 'DEFAULT',
+    default_pkg_key => {
+        type    => Params::Validate::SCALAR,
+        default => 'DEFAULT',
     },
 
-    callbacks =>
-    { type      => Params::Validate::ARRAYREF,
-      optional  => 1,
+    callbacks => {
+        type     => Params::Validate::ARRAYREF,
+        optional => 1,
     },
 
-    pre_callbacks =>
-    { type      => Params::Validate::ARRAYREF,
-      optional  => 1,
+    pre_callbacks => {
+        type     => Params::Validate::ARRAYREF,
+        optional => 1,
     },
 
-    post_callbacks =>
-    { type      => Params::Validate::ARRAYREF,
-      optional  => 1,
+    post_callbacks => {
+        type     => Params::Validate::ARRAYREF,
+        optional => 1,
     },
 
-    cb_classes =>
-    { type      => Params::Validate::ARRAYREF | Params::Validate::SCALAR,
-      callbacks => { 'valid cb_classes' => $valid_cb_classes },
-      optional  => 1,
+    cb_classes => {
+        type      => Params::Validate::ARRAYREF | Params::Validate::SCALAR,
+        callbacks => { 'valid cb_classes' => $valid_cb_classes },
+        optional  => 1,
     },
 
-    ignore_nulls =>
-    { type      => Params::Validate::BOOLEAN,
-      default   => 0,
+    ignore_nulls => {
+        type    => Params::Validate::BOOLEAN,
+        default => 0,
     },
 
-    exception_handler =>
-    { type      => Params::Validate::CODEREF,
-      default   => $exception_handler
+    exception_handler => {
+        type    => Params::Validate::CODEREF,
+        default => $exception_handler
     },
 
-    leave_notes =>
-    { type      => Params::Validate::BOOLEAN,
-      default   => 0,
+    leave_notes => {
+        type    => Params::Validate::BOOLEAN,
+        default => 0,
     },
-  );
+);
 
 BEGIN {
     # Load up any callback class definitions.
@@ -348,11 +350,11 @@ Functional parameter-triggered callbacks:
   }
 
   # Set up a callback request object.
-  my $cb_request = Params::CallbackRequest
-    ( callbacks => [ { cb_key  => 'calc_time',
+  my $cb_request = Params::CallbackRequest->new(
+      callbacks => [ { cb_key  => 'calc_time',
                        pkg_key => 'myCallbacker',
                        cb      => \&calc_time } ]
-    );
+  );
 
   # Request callback execution.
   my %params = ('myCallbacker|calc_time_cb' => 1);
@@ -1008,11 +1010,6 @@ he borrowed from Paul Lindner's work with Apache::ASP. My thanks to them both
 for planting this great idea! This implementation is however completely
 independent of previous implementations.
 
-=head1 BUGS
-
-Please report all bugs via the CPAN Request Tracker at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Params-CallbackRequest>.
-
 =head1 SEE ALSO
 
 L<Params::Callback|Params::Callback> objects get passed as the sole argument
@@ -1024,13 +1021,24 @@ create callback classes and methods.
 L<MasonX::Interp::WithCallbacks|MasonX::Intper::WithCallbacks> uses this
 module to provide a callback architecture for HTML::Mason.
 
+=head1 SUPPORT
+
+This module is stored in an open L<GitHub
+repository|http://github.com/theory/params-callbackrequest/>. Feel free to
+fork and contribute!
+
+Please file bug reports via L<GitHub
+Issues|http://github.com/theory/params-callbackrequest/issues/> or by sending
+mail to
+L<bug-params-callbackrequest@rt.cpan.org|mailto:bug-params-callbackrequest@rt.cpan.org>.
+
 =head1 AUTHOR
 
-David Wheeler <david@kineticode.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by David Wheeler
+Copyright 2003-2011 David E. Wheeler. Some Rights Reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
